Struct shared_bus::proxy::BusProxy
source · Expand description
A proxy type that can be used instead of an actual bus peripheral.
BusProxy implements all bus traits and can thus be used in place of the
actual bus peripheral.
BusProxies are created by calling BusManager::acquire