Type Definition shared_bus::BusManagerStd [−][src]
type BusManagerStd<BUS> = BusManager<Mutex<BUS>>;
A bus manager for safely sharing between threads on a platform with std support.
This manager internally uses a std::sync::Mutex for synchronizing bus accesses. As sharing
across threads will in most cases require a manager with 'static lifetime, the
shared_bus::new_std!() macro exists to create such a bus manager.
This type is only available with the std feature.